@@ -20,7 +20,10 @@ from pystencils.integer_functions import (
 try:
     from sympy.printing.ccode import C99CodePrinter as CCodePrinter
 except ImportError:
-    from sympy.printing.ccode import CCodePrinter  # for sympy versions < 1.1
+    try:
+        from sympy.printing.ccode import CCodePrinter  # for sympy versions < 1.1
+    except ImportError:
+        from sympy.printing.c import C11CodePrinter as CCodePrinter  # for sympy versions > 1.6
 
 __all__ = ['generate_c', 'CustomCodeNode', 'PrintNode', 'get_headers', 'CustomSympyPrinter']
 
@@ -42,9 +45,11 @@ def generate_c(ast_node: Node,
     create_kernel functions.
 
     Args:
-        ast_node:
-        signature_only:
-        dialect: 'c' or 'cuda'
+        ast_node: ast representation of kernel
+        signature_only: generate signature without function body
+        dialect: 'c', 'cuda' or opencl
+        custom_backend: use own custom printer for code generation
+        with_globals: enable usage of global variables
     Returns:
         C-like code for the ast node and its descendants
     """
